#[derive(Debug)]Expand description
The trait and macro from the standard library. Only the trait is actually exposed by this crate.
Derive macro generating an impl of the trait Debug.
#[derive(Debug)]The trait and macro from the standard library. Only the trait is actually exposed by this crate.
Derive macro generating an impl of the trait Debug.